Using the CLI
=============
Bio2BEL automatically installs a command line interface with Python's entry-points. It can be accessed with either
``python3 -m bio2bel`` or just as ``bio2bel`` from your favorite terminal.

It dynamically loads all Bio2BEL modules installed so commands are aliased.

- ``bio2bel_mirtarbase populate`` can be accessed as ``bio2bel mirtarbase populate``
- ``bio2bel populate`` runs all possible repositories' populate commands.
